package com.ruoyi.branch.service;

import java.util.List;
import com.ruoyi.branch.domain.TBranchActivity;

/**
 * 支部特色活动Service接口
 * 
 * @author ruoyi
 * @date 2023-07-18
 */
public interface ITBranchActivityService 
{
    /**
     * 查询支部特色活动
     * 
     * @param activityId 支部特色活动主键
     * @return 支部特色活动
     */
    public TBranchActivity selectTBranchActivityByActivityId(Long activityId);

    /**
     * 查询支部特色活动列表
     * 
     * @param tBranchActivity 支部特色活动
     * @return 支部特色活动集合
     */
    public List<TBranchActivity> selectTBranchActivityList(TBranchActivity tBranchActivity);

    /**
     * 新增支部特色活动
     * 
     * @param tBranchActivity 支部特色活动
     * @return 结果
     */
    public int insertTBranchActivity(TBranchActivity tBranchActivity);

    /**
     * 修改支部特色活动
     * 
     * @param tBranchActivity 支部特色活动
     * @return 结果
     */
    public int updateTBranchActivity(TBranchActivity tBranchActivity);

    /**
     * 批量删除支部特色活动
     * 
     * @param activityIds 需要删除的支部特色活动主键集合
     * @return 结果
     */
    public int deleteTBranchActivityByActivityIds(Long[] activityIds);

    /**
     * 删除支部特色活动信息
     * 
     * @param activityId 支部特色活动主键
     * @return 结果
     */
    public int deleteTBranchActivityByActivityId(Long activityId);
}
